@@ -1,6 +1,6 @@
 from jobsworthy.util import error
 
-class ObserverError(error.JobError):
+class ObserverError(error.JobsWorthyError):
     pass
 
 class ObserverConfigError(ObserverError):
