@@ -11,7 +11,7 @@ from jobsworthy.observer import repo
 from jobsworthy import repo as hive_repo
 from jobsworthy.util import monad, validate, logger
 from jobsworthy.observer.domain import metrics
-from jobsworthy.structure import structure
+from jobsworthy import structure as S
 
 
 class Observable:
@@ -37,9 +37,6 @@ class Observable:
 
 class DataSet(Observable):
     type_of = None
-
-
-class Hive(DataSet):
     dataset_namespace = None
 
     @classmethod
@@ -53,6 +50,19 @@ class Hive(DataSet):
         return self.dataset_namespace
 
 
+
+class Hive(DataSet):
+    pass
+
+
+class EventTable(DataSet):
+    pass
+
+
+class ObjectStore(DataSet):
+    pass
+
+
 class HiveTable(Hive):
     type_of = Observable.sfo_lin.HiveTable
 
@@ -75,16 +85,27 @@ class HiveTable(Hive):
         )
 
 
-class ObjectStore(DataSet):
-    @classmethod
-    def namespace(cls, namespace):
-        cls.dataset_namespace = namespace
-        return cls
+class CosmosEventTable(EventTable):
+    type_of = Observable.sfo_lin.CosmosEventTable
+
+    def __init__(self, table_name, fully_qualified_name):
+        self.table_name = table_name
+        self.fully_qualified_name = fully_qualified_name
 
     def dataset_identity(self):
         return self.namespace_uri()
 
-    pass
+    def identity(self):
+        return self.dataset_identity().term(self.fully_qualified_name)
+
+    def to_props(self):
+        return (
+            self.coerce_uri(self.identity()),
+            self.coerce_uri(self.type_of),
+            self.fully_qualified_name,
+            self.table_name
+        )
+
 
 
 class ObjectStoreFile(ObjectStore):
@@ -190,6 +211,14 @@ class Run(Job):
         return self
 
     def with_state_transition(self, transition_fn: Callable):
+        """
+        The Transition fn is provided by the caller, and is expected to return a tuple containing
+        (new_state, transition_event).  It takes a current state in the format which is understood by the transition
+        function.
+
+        The state returned must either be a string or a ENUM-like object that has a value attribute which returns a
+        string.
+        """
         new_current_state, event = transition_fn(self.current_state)
         self.state_transitions.append({'from': self.current_state, 'with': event, 'to': new_current_state})
         self.current_state = new_current_state
@@ -268,7 +297,7 @@ class Run(Job):
                 "traceId": self.coerce_uri(self.trace) if self.trace else None,
                 "startTime": self.start_time.to_iso8601_string() if self.start_time else None,
                 "endTime": self.end_time.to_iso8601_string() if self.end_time else None,
-                "state": self.current_state}
+                "state": self.current_state if isinstance(self.current_state, str) else self.current_state.value}
         )
         self.inputs_as_props(row)
         self.outputs_as_props(row)
@@ -369,7 +398,7 @@ class ObserverHiveEmitter(Emitter):
         return [row.build_ordered_row_values() for row in self.runs_to_rows(table, runs)]
 
     def all_rows_ok(self, rows):
-        return all(map(structure.all_cells_ok, rows))
+        return all(map(S.all_cells_ok, rows))
 
     def create_df(self, table, runs: List[Run]):
         return self.repo.create_df(self.build_rows(table, runs), table.hive_schema())
@@ -451,7 +480,7 @@ def observer_factory(env: str, job: Job, emitter: Emitter) -> Observer:
 
 
 def define_namespace(cls, uri: str) -> None:
-    if not cls in [SparkJob, Hive, ObjectStore]:
+    if not cls in [SparkJob, Hive, ObjectStore, EventTable]:
         raise error.ObserverConfigError("Namespace must be configured on SparkJob, Hive, or ObjectStore")
     if not validate.valid_uri(uri):
         raise error.ObserverConfigError("Namespace must be a valid URI")
