@@ -1,4 +1,5 @@
 from .config import (
+    Config,
     JobConfig,
     DbConfig,
     CosmosDbConfig
@@ -6,5 +7,6 @@ from .config import (
 
 from .spark_job import (
     job,
-    register
+    register,
+    simple_streaming_job
 )
