@@ -1,4 +1,4 @@
-from pyspark.sql.types import StructType, StructField, StringType, ArrayType
+from pyspark.sql.types import StructType, StructField, StringType, ArrayType, LongType
 
 from jobsworthy.structure import vocab_util as V
 
@@ -51,6 +51,11 @@ def build_decimal_field(vocab_path, vocab, decimal_type, nullable) -> StructFiel
     return build_field(term, decimal_type, metadata=meta, nullable=nullable)
 
 
+def build_long_field(vocab_path, vocab, nullable) -> StructField:
+    term, meta = V.term_and_meta(vocab_path, vocab)
+    return build_field(term, LongType(), metadata=meta, nullable=nullable)
+
+
 def build_array_field(vocab_path, vocab, struct_type, nullable) -> StructField:
     term, meta = V.term_and_meta(vocab_path, vocab)
     return build_field(term, ArrayType(struct_type), metadata=meta, nullable=nullable)
@@ -60,18 +65,22 @@ def build_struct_field(vocab_path: str, vocab, struct_type: StructType, nullable
     term, meta = V.term_and_meta(vocab_path, vocab)
     return build_field(term, struct_type, metadata=meta, nullable=nullable)
 
-# to build a field with type as a parameter. 
+
+# to build a field with type as a parameter.
 # e.g. build_type_field('path',vocab, IntegerType(), nullable=False) creates an integer type field
 def build_type_field(vocab_path, vocab, field_type, nullable) -> StructField:
     term, meta = V.term_and_meta(vocab_path, vocab)
     return build_field(term, field_type, metadata=meta, nullable=nullable)
 
+
 at_id = build_string_field("*.@id", common_vocab, nullable=False)
 
 optional_at_id = build_string_field("*.@id", common_vocab, nullable=True)
 
 at_type = build_string_field("*.@type", common_vocab, nullable=False)
 
+at_type_array = build_array_field("*.@type", common_vocab, StringType(), nullable=False)
+
 label = build_string_field("*.lcc-lr:hasTag", common_vocab, nullable=True)
 
 type_id_label_struct = StructType([
